package server.command;

import server.network.User;

public enum UserPolicy {
	EVERYONE("Wie haste denn das nu geschafft??!") {
		public boolean applies(CommandEnvironment env, Executor exec, User user) {
			return true;
		}
	},
	NON_ADMINS("Spieler ist ein Admin") {
		public boolean applies(CommandEnvironment env, Executor exec, User user) {
			return !user.isAdmin() || exec.isConsole();
		}
	},
	NON_ADMINS_STRICT("Spieler ist ein Admin") {
		public boolean applies(CommandEnvironment env, Executor exec, User user) {
			return !user.isAdmin();
		}
	},
	ADMINS("Spieler ist kein Admin") {
		public boolean applies(CommandEnvironment env, Executor exec, User user) {
			return user.isAdmin();
		}
	},
	NOT_SELF("Diese Aktion kann nur an anderen Spielern ausgeführt werden") {
		public boolean applies(CommandEnvironment env, Executor exec, User user) {
			return user != exec;
		}
	},
	NON_ADMINS_NOT_SELF("Diese Aktion kann nur an anderen Spielern ohne Admin-Status ausgeführt werden") {
		public boolean applies(CommandEnvironment env, Executor exec, User user) {
			return (!user.isAdmin() || exec.isConsole()) && user != exec;
		}
	},
	NON_ADMINS_OR_SELF("Spieler ist ein Admin") {
		public boolean applies(CommandEnvironment env, Executor exec, User user) {
			return !user.isAdmin() || user == exec || exec.isConsole();
		}
	};
	
	private final String denyMessage;
	
	private UserPolicy(String denyMessage) {
		this.denyMessage = denyMessage;
	}
	
	public String getDenyMessage(User user) {
		return String.format("%s: %s", user.getUser(), this.denyMessage);
	}
	
	public abstract boolean applies(CommandEnvironment env, Executor exec, User user);
}
